@@ -21,14 +21,14 @@ from .qubit_mapper import QubitMapper
 
 
 class SpinMapper(QubitMapper):
-    """ Mapper of Spin Operator to Qubit Operator """
+    """Mapper of Spin Operator to Qubit Operator"""
 
     @abstractmethod
     def map(self, second_q_op: SpinOp) -> PauliSumOp:
-        """Maps a class:`SpinOp` to a `PauliSumOp`.
+        """Maps a :class:`~qiskit_nature.operators.second_quantization.SpinOp` to a `PauliSumOp`.
 
         Args:
-            second_q_op: the :class:`SpinOp` to be mapped.
+            second_q_op: the `SpinOp` to be mapped.
 
         Returns:
             The `PauliSumOp` corresponding to the problem-Hamiltonian in the qubit space.
