@@ -1,6 +1,6 @@
 # This code is part of Qiskit.
 #
-# (C) Copyright IBM 2021.
+# (C) Copyright IBM 2021, 2022.
 #
 # This code is licensed under the Apache License, Version 2.0. You may
 # obtain a copy of this license in the LICENSE.txt file in the root directory
@@ -12,7 +12,11 @@
 
 """The OccupiedModals property."""
 
-from typing import List, Optional, Tuple
+from __future__ import annotations
+
+from typing import Optional
+
+import h5py
 
 from qiskit_nature import ListOrDictType, settings
 from qiskit_nature.drivers import WatsonHamiltonian
@@ -22,6 +26,7 @@ from qiskit_nature.results import EigenstateResult
 from ..second_quantized_property import LegacyDriverResult
 from .bases import VibrationalBasis
 from .types import VibrationalProperty
+from ....deprecation import deprecate_method
 
 
 class OccupiedModals(VibrationalProperty):
@@ -40,8 +45,24 @@ class OccupiedModals(VibrationalProperty):
         """
         super().__init__(self.__class__.__name__, basis)
 
+    @staticmethod
+    def from_hdf5(h5py_group: h5py.Group) -> OccupiedModals:
+        # pylint: disable=unused-argument
+        """Constructs a new instance from the data stored in the provided HDF5 group.
+
+        See also :func:`~qiskit_nature.hdf5.HDF5Storable.from_hdf5` for more details.
+
+        Args:
+            h5py_group: the HDF5 group from which to load the data.
+
+        Returns:
+            A new instance of this class.
+        """
+        return OccupiedModals()
+
     @classmethod
-    def from_legacy_driver_result(cls, result: LegacyDriverResult) -> "OccupiedModals":
+    @deprecate_method("0.4.0")
+    def from_legacy_driver_result(cls, result: LegacyDriverResult) -> OccupiedModals:
         """Construct an OccupiedModals instance from a
         :class:`~qiskit_nature.drivers.WatsonHamiltonian`.
 
@@ -86,14 +107,13 @@ class OccupiedModals(VibrationalProperty):
         """
         num_modals_per_mode = self.basis._num_modals_per_mode
 
-        labels: List[Tuple[str, complex]] = []
+        labels: list[tuple[str, complex]] = []
 
         for modal in range(num_modals_per_mode[mode]):
             labels.append((f"+_{mode}*{modal} -_{mode}*{modal}", 1.0))
 
         return VibrationalOp(labels, len(num_modals_per_mode), num_modals_per_mode)
 
-    # TODO: refactor after closing https://github.com/Qiskit/qiskit-terra/issues/6772
     def interpret(self, result: EigenstateResult) -> None:
         """Interprets an :class:`~qiskit_nature.results.EigenstateResult` in this property's context.
 
@@ -105,7 +125,7 @@ class OccupiedModals(VibrationalProperty):
         if not isinstance(result.aux_operator_eigenvalues, list):
             aux_operator_eigenvalues = [result.aux_operator_eigenvalues]
         else:
-            aux_operator_eigenvalues = result.aux_operator_eigenvalues  # type: ignore[assignment]
+            aux_operator_eigenvalues = result.aux_operator_eigenvalues
 
         num_modes = len(self._basis._num_modals_per_mode)
 
@@ -114,7 +134,7 @@ class OccupiedModals(VibrationalProperty):
             for mode in range(num_modes):
                 _key = str(mode) if isinstance(aux_op_eigenvalues, dict) else mode
                 if aux_op_eigenvalues[_key] is not None:
-                    occ_modals.append(aux_op_eigenvalues[_key][0].real)  # type: ignore
+                    occ_modals.append(aux_op_eigenvalues[_key][0].real)
                 else:
                     occ_modals.append(None)
-            result.num_occupied_modals_per_mode.append(occ_modals)  # type: ignore
+            result.num_occupied_modals_per_mode.append(occ_modals)
