@@ -1,6 +1,6 @@
 # This code is part of Qiskit.
 #
-# (C) Copyright IBM 2021.
+# (C) Copyright IBM 2021, 2022.
 #
 # This code is licensed under the Apache License, Version 2.0. You may
 # obtain a copy of this license in the LICENSE.txt file in the root directory
@@ -21,13 +21,3 @@ Transformers (:mod:`qiskit_nature.transformers`)
 
    second_quantization
 """
-
-from .active_space_transformer import ActiveSpaceTransformer
-from .base_transformer import BaseTransformer
-from .freeze_core_transformer import FreezeCoreTransformer
-
-__all__ = [
-    "ActiveSpaceTransformer",
-    "BaseTransformer",
-    "FreezeCoreTransformer",
-]
