@@ -1,6 +1,6 @@
 # This code is part of Qiskit.
 #
-# (C) Copyright IBM 2021.
+# (C) Copyright IBM 2021, 2022.
 #
 # This code is licensed under the Apache License, Version 2.0. You may
 # obtain a copy of this license in the LICENSE.txt file in the root directory
@@ -13,16 +13,18 @@
 """Test AngularMomentum Property"""
 
 import json
+import tempfile
 import warnings
-from test import QiskitNatureTestCase
+from test.properties.property_test import PropertyTest
 
-import numpy as np
+import h5py
 
 from qiskit_nature.drivers import QMolecule
 from qiskit_nature.properties.second_quantization.electronic import AngularMomentum
+from qiskit_nature.operators.second_quantization import FermionicOp
 
 
-class TestAngularMomentum(QiskitNatureTestCase):
+class TestAngularMomentum(PropertyTest):
     """Test AngularMomentum Property"""
 
     def setUp(self):
@@ -36,8 +38,7 @@ class TestAngularMomentum(QiskitNatureTestCase):
 
     def test_second_q_ops(self):
         """Test second_q_ops."""
-        ops = self.prop.second_q_ops()
-        self.assertEqual(len(ops), 1)
+        op = self.prop.second_q_ops()["AngularMomentum"]
         with open(
             self.get_resource_path(
                 "angular_momentum_op.json", "properties/second_quantization/electronic/resources"
@@ -46,6 +47,22 @@ class TestAngularMomentum(QiskitNatureTestCase):
             encoding="utf8",
         ) as file:
             expected = json.load(file)
-        for op, expected_op in zip(ops[0].to_list(), expected):
-            self.assertEqual(op[0], expected_op[0])
-            self.assertTrue(np.isclose(op[1], expected_op[1]))
+            expected_op = FermionicOp(expected).simplify()
+        self.assertSetEqual(frozenset(op.to_list("dense")), frozenset(expected_op.to_list("dense")))
+
+    def test_to_hdf5(self):
+        """Test to_hdf5."""
+        with tempfile.TemporaryFile() as tmp_file:
+            with h5py.File(tmp_file, "w") as file:
+                self.prop.to_hdf5(file)
+
+    def test_from_hdf5(self):
+        """Test from_hdf5."""
+        with tempfile.TemporaryFile() as tmp_file:
+            with h5py.File(tmp_file, "w") as file:
+                self.prop.to_hdf5(file)
+
+            with h5py.File(tmp_file, "r") as file:
+                read_prop = AngularMomentum.from_hdf5(file["AngularMomentum"])
+
+                self.assertEqual(self.prop, read_prop)
